==> haskell-filemanip-0.3.6.3-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filemanip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filemanip
version:              0.3.6.3
visibility:           public
id:                   filemanip-0.3.6.3-FOuab9nteZ95JS82X2oAUO
key:                  filemanip-0.3.6.3-FOuab9nteZ95JS82X2oAUO
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/filemanip
synopsis:             Expressive file and directory manipulation for Haskell.
description:
    A Haskell library for working with files and directories.
    Includes code for pattern matching, finding files,
    modifying file contents, and more.

category:             System
abi:                  392ed33f966823080433b5e3a4dc50ac
exposed:              True
exposed-modules:
    System.FilePath.Find System.FilePath.Glob
    System.FilePath.GlobPattern System.FilePath.Manip

import-dirs:          /usr/lib/ghc-8.10.2/site-local/filemanip-0.3.6.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/filemanip-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/filemanip-0.3.6.3
hs-libraries:         HSfilemanip-0.3.6.3-FOuab9nteZ95JS82X2oAUO
depends:
    base-4.14.1.0 bytestring-0.10.10.0 directory-1.3.6.0
    filepath-1.4.2.1 mtl-2.2.2 unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP

haddock-interfaces:   /usr/share/doc/haskell-filemanip/html/filemanip.haddock
haddock-html:         /usr/share/doc/haskell-filemanip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filemanip-0.3.6.3-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filemanip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filemanip
version:              0.3.6.3
visibility:           public
id:                   filemanip-0.3.6.3-4Y8G3hE2pJJ8Zg9qpvRsH
key:                  filemanip-0.3.6.3-4Y8G3hE2pJJ8Zg9qpvRsH
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/filemanip
synopsis:             Expressive file and directory manipulation for Haskell.
description:
    A Haskell library for working with files and directories.
    Includes code for pattern matching, finding files,
    modifying file contents, and more.

category:             System
abi:                  e09f341831947c14c2243c44a45421d7
exposed:              True
exposed-modules:
    System.FilePath.Find System.FilePath.Glob
    System.FilePath.GlobPattern System.FilePath.Manip

import-dirs:          /usr/lib/ghc-8.10.3/site-local/filemanip-0.3.6.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/filemanip-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/filemanip-0.3.6.3
hs-libraries:         HSfilemanip-0.3.6.3-4Y8G3hE2pJJ8Zg9qpvRsH
depends:
    base-4.14.1.0 bytestring-0.10.12.0 directory-1.3.6.0
    filepath-1.4.2.1 mtl-2.2.2 unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP

haddock-interfaces:   /usr/share/doc/haskell-filemanip/html/filemanip.haddock
haddock-html:         /usr/share/doc/haskell-filemanip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
